<?php 

namespace FiloBlu\PrivacyPolicy\Setup;

use Magento\Cms\Api\BlockRepositoryInterface;
use Magento\Cms\Api\Data\BlockInterface;
use Magento\Cms\Api\Data\BlockInterfaceFactory;
use Magento\Framework\App\State;
use Magento\Framework\App\Area;
use Magento\Framework\Setup\InstallDataInterface;
use Magento\Framework\Setup\ModuleContextInterface;
use Magento\Framework\Setup\ModuleDataSetupInterface;
use Magento\Store\Model\Store;
use Magento\Customer\Model\Customer;
use Magento\Customer\Setup\CustomerSetupFactory;
use Magento\Eav\Model\Entity\Attribute\Set as AttributeSet;
use Magento\Eav\Model\Entity\Attribute\SetFactory as AttributeSetFactory;

class InstallData implements InstallDataInterface
{

 
     /**
     * EAV setup factory
     *
     * @var CustomerSetupFactory
     */
    private $customerSetupFactory;

    private $attributeSet;
    private $attributeSetFactory;

    /** @var  BlockRepositoryInterface */
    private $blockRepository;

    /** @var BlockFactory */
    private $blockInterfaceFactory;

    /** @var State */
    private $state;
    
  
  /**
     * InstallData constructor.
     * @param BlockRepositoryInterface $blockRepository
     * @param BlockInterfaceFactory $blockInterfaceFactory
     */
    public function __construct(
        CustomerSetupFactory $customerSetupFactory,
        AttributeSet $attributeSet,
        AttributeSetFactory $attributeSetFactory,
        BlockRepositoryInterface $blockRepository,
        BlockInterfaceFactory $blockInterfaceFactory,
        State $state
    ) {
        $this->customerSetupFactory = $customerSetupFactory;
        $this->attributeSet = $attributeSet;
        $this->attributeSetFactory = $attributeSetFactory;
        $this->blockRepository = $blockRepository;
        $this->blockInterfaceFactory = $blockInterfaceFactory;
        $this->state = $state;
    }
  
    /**
     * Installs data for a module
     *
     * @param ModuleDataSetupInterface $setup
     * @param ModuleContextInterface $context
     * @return void
     */
    public function install(ModuleDataSetupInterface $setup, ModuleContextInterface $context)
    {
            $setup->startSetup();

            $customerSetup = $this->customerSetupFactory->create(['setup' => $setup]);
                  
            $customerSetup->addAttribute(Customer::ENTITY, 'privacy_version_accepted', [
                'type' => 'int',
                'label' => 'Privacy Policy Version Accepted',
                'input' => 'text',
                'required' => false,
                'visible' => false,
                'source' => '',
                'backend' => '',
                'user_defined' => true,
                'is_user_defined' => true,
                'sort_order' => 1000,
                'is_used_in_grid' => false,
                'is_visible_in_grid' => false,
                'is_filterable_in_grid' => false,
                'is_searchable_in_grid' => false,
                'position' => 1000,
                'system' => 0,
            ]);

            $attributeSet = $this->attributeSetFactory->create();
            $attributeGroupId = $attributeSet->getDefaultGroupId(\Magento\Customer\Api\CustomerMetadataInterface::ATTRIBUTE_SET_ID_CUSTOMER);

            $attribute = $customerSetup->getEavConfig()->getAttribute('customer', 'privacy_version_accepted')->addData([
                'attribute_set_id' => \Magento\Customer\Api\CustomerMetadataInterface::ATTRIBUTE_SET_ID_CUSTOMER,
                'attribute_group_id' => $attributeGroupId,
                'used_in_forms' => [
                    'customer_account_edit', 'adminhtml_customer'
                ]
            ]);
            $attribute->save();

            $attribute = $customerSetup->getEavConfig()->getAttribute(Customer::ENTITY, 'privacy_version_accepted')
            ->addData(['used_in_forms' => [
                'adminhtml_customer',
                'adminhtml_checkout',
                'customer_account_create',
                'customer_account_edit'
                ]
            ]);

            $attribute->save();

            /** set Area code to prevent the Exception during setup:upgrade */
            $this->state->setAreaCode(Area::AREA_ADMINHTML);
      
            /** @var BlockInterface $cmsBlock */
            $cmsBlock = $this->blockInterfaceFactory->create();

            $content = <<<HTML
<div>Lorem ipsum dolor sit amet, consectetur adipiscing elit. Suspendisse mauris tortor, 
rhoncus at diam ac, aliquet egestas elit. Integer varius, ipsum et imperdiet scelerisque, 
lorem magna feugiat arcu, sed rhoncus velit magna a velit.</div> 
HTML;

            $cmsBlock->setIdentifier('privacy_policy_popup_content');
            $cmsBlock->setTitle('Privacy Policy Popup Content');
            $cmsBlock->setContent($content);
            $cmsBlock->setData('stores', [Store::DEFAULT_STORE_ID]); // DEFAULT_STORE_ID = 0

            $this->blockRepository->save($cmsBlock);

            $setup->endSetup();
    }
}